@@ -188,6 +188,7 @@ typedef enum NormEventType
     NORM_RX_OBJECT_UPDATED,
     NORM_RX_OBJECT_COMPLETED,
     NORM_RX_OBJECT_ABORTED,
+    NORM_RX_ACK_REQUEST,         // upon receipt of app-extended watermark ack request
     NORM_GRTT_UPDATED,
     NORM_CC_ACTIVE,
     NORM_CC_INACTIVE,
@@ -329,7 +330,17 @@ void NormSetTxOnly(NormSessionHandle sessionHandle,
                    bool              connectToSessionAddress DEFAULT(false));
 
 NORM_API_LINKAGE
-void NormSetId(NormSessionHandle sessionHandle, NormNodeId normId);
+void NormLimitObjectInfo(NormSessionHandle sessionHandle, bool state);  // if true, FEC OTI in NORM_INFO only
+
+NORM_API_LINKAGE
+bool NormPresetObjectInfo(NormSessionHandle  sessionHandle,             // FEC OTI is preset and not sent
+                          unsigned long      objectSize,                // (most useful for NORM_OBJECT_STREAM)
+                          UINT16             segmentSize, 
+                          UINT16             numData, 
+                          UINT16             numParity);
+// non-public on purpose
+//NORM_API_LINKAGE
+//void NormSetId(NormSessionHandle sessionHandle, NormNodeId normId);
 
 // This does not affect the rx_socket binding if already bound (sender or receiver already started)
 // (i.e., just affects where NORM packets are sent)
@@ -356,6 +367,9 @@ void NormSetRxPortReuse(NormSessionHandle sessionHandle,
 NORM_API_LINKAGE
 UINT16 NormGetRxPort(NormSessionHandle sessionHandle);
 
+NORM_API_LINKAGE
+bool NormGetRxBindAddress(NormSessionHandle sessionHandle, char* addr, unsigned int& addrLen, UINT16& port);
+
 // TBD - We should probably have a "NormSetCCMode(NormCCMode ccMode)" function for users
 NORM_API_LINKAGE
 void NormSetEcnSupport(NormSessionHandle  sessionHandle, 
@@ -501,6 +515,10 @@ void NormSetGrttProbingInterval(NormSessionHandle sessionHandle,
                                 double            intervalMin,
                                 double            intervalMax);
 
+NORM_API_LINKAGE
+void NormSetGrttProbingTOS(NormSessionHandle sessionHandle,
+                           UINT8              probeTOS);
+
 NORM_API_LINKAGE 
 void NormSetBackoffFactor(NormSessionHandle sessionHandle,
                           double            backoffFactor);
@@ -569,6 +587,9 @@ void NormStreamSetPushEnable(NormObjectHandle streamHandle,
 NORM_API_LINKAGE 
 bool NormStreamHasVacancy(NormObjectHandle streamHandle);
 
+NORM_API_LINKAGE
+unsigned int NormStreamGetVacancy(NormObjectHandle streamHandle, unsigned int bytesWanted = 0);
+
 NORM_API_LINKAGE 
 void NormStreamMarkEom(NormObjectHandle streamHandle);
 
@@ -576,6 +597,15 @@ NORM_API_LINKAGE
 bool NormSetWatermark(NormSessionHandle  sessionHandle,
                       NormObjectHandle   objectHandle,
                       bool               overrideFlush DEFAULT(false));
+
+NORM_API_LINKAGE 
+bool NormSetWatermarkEx(NormSessionHandle  sessionHandle,
+                        NormObjectHandle   objectHandle,
+                        const char*        buffer,
+                        unsigned int       numBytes,
+                        bool               overrideFlush DEFAULT(false));
+
+
 NORM_API_LINKAGE 
 bool NormResetWatermark(NormSessionHandle sessionHandle);
 
@@ -607,6 +637,12 @@ bool NormGetNextAckingNode(NormSessionHandle    sessionHandle,
                            NormNodeId*          nodeId,   
                            NormAckingStatus*    ackingStatus DEFAULT(0));
 
+NORM_API_LINKAGE
+bool NormGetAckEx(NormSessionHandle sessionHandle,
+                  NormNodeId        nodeId,   
+                  char*             buffer,
+                  unsigned int*     buflen);
+
 NORM_API_LINKAGE 
 bool NormSendCommand(NormSessionHandle  sessionHandle,
                      const char*        cmdBuffer, 
@@ -784,6 +820,16 @@ bool NormNodeGetCommand(NormNodeHandle remoteSender,
                         char*          buffer,
                         unsigned int*  buflen);
 
+NORM_API_LINKAGE
+bool NormNodeSendAckEx(NormNodeHandle remoteSender,
+                       const char*    buffer,
+                       unsigned int   numBytes);
+
+NORM_API_LINKAGE
+bool NormNodeGetWatermarkEx(NormNodeHandle remoteSender,
+                            char*          buffer,
+                            unsigned int*  buflen);
+
 NORM_API_LINKAGE
 void NormNodeFreeBuffers(NormNodeHandle remoteSender);
 
